@@ -3,6 +3,7 @@ import itertools
 from copy import deepcopy
 from collections import deque
 from typing import TYPE_CHECKING, Optional, Iterator, Any, List, Callable, Dict
+import warnings
 
 from . import component as comp
 from . import rdltypes
@@ -91,7 +92,17 @@ class Node:
         name : str
             Derived property name
             If unassigned, will default to the function's name
+
+        .. deprecated:: 1.15
+            Use of this function is not recommended since it encourages the bad
+            practice of modifying the SystemRDL API at runtime. Instead, it is
+            recommended that any extended property derivations be done in a
+            separate function outside of the Node interface.
+
+            In future revisions, use of this function will emit a warning, and will
+            eventually be removed entirely.
         """
+        warnings.warn("deprecated", DeprecationWarning)
 
         if name is None:
             name = getter_function.__name__
